==> jc-1.4.0.tar.gz: javax/xml/transform/sax/SAXTransformerFactory.h <==
// public abstract class javax.xml.transform.sax.SAXTransformerFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 785909bf3cc2d46 javax_xml_transform_TransformerFactory
// @dep_class 40837975dbd5b504 javax_xml_transform_sax_SAXTransformerFactory

// header file dependencies
// @dep_header javax_xml_transform_TransformerFactory

#include "javax/xml/transform/TransformerFactory.h"

#ifndef _JC_javax_xml_transform_sax_SAXTransformerFactory_H_
#define _JC_javax_xml_transform_sax_SAXTransformerFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_transform_Source$object;
struct _jc_javax_xml_transform_Templates$object;
struct _jc_javax_xml_transform_sax_TemplatesHandler$object;
struct _jc_javax_xml_transform_sax_TransformerHandler$object;
struct _jc_org_xml_sax_XMLFilter$object;

// Typedefs
typedef struct _jc_javax_xml_transform_sax_SAXTransformerFactory$sub_refs	_jc_javax_xml_transform_sax_SAXTransformerFactory$sub_refs;
typedef struct _jc_javax_xml_transform_sax_SAXTransformerFactory$sub_nonrefs	_jc_javax_xml_transform_sax_SAXTransformerFactory$sub_nonrefs;
typedef struct _jc_javax_xml_transform_sax_SAXTransformerFactory$refs	_jc_javax_xml_transform_sax_SAXTransformerFactory$refs;
typedef struct _jc_javax_xml_transform_sax_SAXTransformerFactory$nonrefs	_jc_javax_xml_transform_sax_SAXTransformerFactory$nonrefs;
typedef struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object	_jc_javax_xml_transform_sax_SAXTransformerFactory$object;

typedef struct _jc_javax_xml_transform_sax_SAXTransformerFactory$fields_struct	_jc_javax_xml_transform_sax_SAXTransformerFactory$fields_struct;
typedef const struct _jc_javax_xml_transform_sax_SAXTransformerFactory$vmethods	_jc_javax_xml_transform_sax_SAXTransformerFactory$vmethods;
typedef const struct _jc_javax_xml_transform_sax_SAXTransformerFactory$vtable	_jc_javax_xml_transform_sax_SAXTransformerFactory$vtable;
typedef const struct _jc_javax_xml_transform_sax_SAXTransformerFactory$vtype	_jc_javax_xml_transform_sax_SAXTransformerFactory$vtype;

// Class fields structure
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$fields_struct {
	struct _jc_java_lang_String$object	*FEATURE;
	struct _jc_java_lang_String$object	*FEATURE__5fXMLFILTER;
};
extern _jc_javax_xml_transform_sax_SAXTransformerFactory$fields_struct _jc_javax_xml_transform_sax_SAXTransformerFactory$class_fields;

// Constructors
extern void _jc_javax_xml_transform_sax_SAXTransformerFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXTransformerFactory$method$newTemplatesHandler$17a5d9d759402a37(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *);
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXTransformerFactory$method$newTransformerHandler$bb837a0d83afae09(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *);
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXTransformerFactory$method$newTransformerHandler$88c4a0c08a9ede67(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *);
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXTransformerFactory$method$newTransformerHandler$35afbc0e42ee6f52(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *);
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXTransformerFactory$method$newXMLFilter$e60ae9ab4498aaeb(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *);
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXTransformerFactory$method$newXMLFilter$d1211602c6161dca(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_xml_transform_sax_SAXTransformerFactory$method_info$newTemplatesHandler$17a5d9d759402a37;
extern _jc_method _jc_javax_xml_transform_sax_SAXTransformerFactory$method_info$newTransformerHandler$bb837a0d83afae09;
extern _jc_method _jc_javax_xml_transform_sax_SAXTransformerFactory$method_info$newTransformerHandler$88c4a0c08a9ede67;
extern _jc_method _jc_javax_xml_transform_sax_SAXTransformerFactory$method_info$newTransformerHandler$35afbc0e42ee6f52;
extern _jc_method _jc_javax_xml_transform_sax_SAXTransformerFactory$method_info$newXMLFilter$e60ae9ab4498aaeb;
extern _jc_method _jc_javax_xml_transform_sax_SAXTransformerFactory$method_info$newXMLFilter$d1211602c6161dca;

// Virtual methods structure
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$vmethods {
	struct _jc_object	*(*newTemplatesHandler$17a5d9d759402a37)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *);
	struct _jc_object	*(*newTransformerHandler$bb837a0d83afae09)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *);
	struct _jc_object	*(*newTransformerHandler$88c4a0c08a9ede67)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *);
	struct _jc_object	*(*newTransformerHandler$35afbc0e42ee6f52)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *);
	struct _jc_object	*(*newXMLFilter$e60ae9ab4498aaeb)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *);
	struct _jc_object	*(*newXMLFilter$d1211602c6161dca)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_transform_TransformerFactory$vmethods	javax_xml_transform_TransformerFactory;
	_jc_javax_xml_transform_sax_SAXTransformerFactory$vmethods	javax_xml_transform_sax_SAXTransformerFactory;
};

// Vtype
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$vtype {
	_jc_type			type;
	_jc_javax_xml_transform_sax_SAXTransformerFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$refs {
    _jc_javax_xml_transform_sax_SAXTransformerFactory$sub_refs	javax_xml_transform_sax_SAXTransformerFactory;
    _jc_javax_xml_transform_TransformerFactory$sub_refs	javax_xml_transform_TransformerFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_transform_TransformerFactory$sub_nonrefs	javax_xml_transform_TransformerFactory;
    _jc_javax_xml_transform_sax_SAXTransformerFactory$sub_nonrefs	javax_xml_transform_sax_SAXTransformerFactory;
};

// Object instance structure
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object {
	_jc_javax_xml_transform_sax_SAXTransformerFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_transform_sax_SAXTransformerFactory$vtype	*vtype;
	_jc_javax_xml_transform_sax_SAXTransformerFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_transform_sax_SAXTransformerFactory$vtype _jc_javax_xml_transform_sax_SAXTransformerFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_transform_sax_SAXTransformerFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_transform_sax_SAXTransformerFactory$class_object;

#endif	/* _JC_javax_xml_transform_sax_SAXTransformerFactory_H_ */

==> jc-1.4.6.tar.gz: javax/xml/transform/sax/SAXTransformerFactory.h <==
// public abstract class javax.xml.transform.sax.SAXTransformerFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 785909bf3cc2d46 javax_xml_transform_TransformerFactory
// @dep_class 40837975dbd5b504 javax_xml_transform_sax_SAXTransformerFactory

// header file dependencies
// @dep_header javax_xml_transform_TransformerFactory

#include "javax/xml/transform/TransformerFactory.h"

#ifndef _JC_javax_xml_transform_sax_SAXTransformerFactory_H_
#define _JC_javax_xml_transform_sax_SAXTransformerFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_transform_Source$object;
struct _jc_javax_xml_transform_Templates$object;
struct _jc_javax_xml_transform_sax_TemplatesHandler$object;
struct _jc_javax_xml_transform_sax_TransformerHandler$object;
struct _jc_org_xml_sax_XMLFilter$object;

// Typedefs
typedef struct _jc_javax_xml_transform_sax_SAXTransformerFactory$sub_refs	_jc_javax_xml_transform_sax_SAXTransformerFactory$sub_refs;
typedef struct _jc_javax_xml_transform_sax_SAXTransformerFactory$sub_nonrefs	_jc_javax_xml_transform_sax_SAXTransformerFactory$sub_nonrefs;
typedef struct _jc_javax_xml_transform_sax_SAXTransformerFactory$refs	_jc_javax_xml_transform_sax_SAXTransformerFactory$refs;
typedef struct _jc_javax_xml_transform_sax_SAXTransformerFactory$nonrefs	_jc_javax_xml_transform_sax_SAXTransformerFactory$nonrefs;
typedef struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object	_jc_javax_xml_transform_sax_SAXTransformerFactory$object;

typedef struct _jc_javax_xml_transform_sax_SAXTransformerFactory$fields_struct	_jc_javax_xml_transform_sax_SAXTransformerFactory$fields_struct;
typedef const struct _jc_javax_xml_transform_sax_SAXTransformerFactory$vmethods	_jc_javax_xml_transform_sax_SAXTransformerFactory$vmethods;
typedef const struct _jc_javax_xml_transform_sax_SAXTransformerFactory$vtable	_jc_javax_xml_transform_sax_SAXTransformerFactory$vtable;
typedef const struct _jc_javax_xml_transform_sax_SAXTransformerFactory$vtype	_jc_javax_xml_transform_sax_SAXTransformerFactory$vtype;

// Class fields structure
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$fields_struct {
	struct _jc_java_lang_String$object	*FEATURE;
	struct _jc_java_lang_String$object	*FEATURE__5fXMLFILTER;
};
extern _jc_javax_xml_transform_sax_SAXTransformerFactory$fields_struct _jc_javax_xml_transform_sax_SAXTransformerFactory$class_fields;

// Constructors
extern void _jc_javax_xml_transform_sax_SAXTransformerFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXTransformerFactory$method$newTemplatesHandler$17a5d9d759402a37(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXTransformerFactory$method$newTransformerHandler$bb837a0d83afae09(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXTransformerFactory$method$newTransformerHandler$88c4a0c08a9ede67(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXTransformerFactory$method$newTransformerHandler$35afbc0e42ee6f52(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXTransformerFactory$method$newXMLFilter$e60ae9ab4498aaeb(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_xml_transform_sax_SAXTransformerFactory$method$newXMLFilter$d1211602c6161dca(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_xml_transform_sax_SAXTransformerFactory$method_info$newTemplatesHandler$17a5d9d759402a37;
extern _jc_method _jc_javax_xml_transform_sax_SAXTransformerFactory$method_info$newTransformerHandler$bb837a0d83afae09;
extern _jc_method _jc_javax_xml_transform_sax_SAXTransformerFactory$method_info$newTransformerHandler$88c4a0c08a9ede67;
extern _jc_method _jc_javax_xml_transform_sax_SAXTransformerFactory$method_info$newTransformerHandler$35afbc0e42ee6f52;
extern _jc_method _jc_javax_xml_transform_sax_SAXTransformerFactory$method_info$newXMLFilter$e60ae9ab4498aaeb;
extern _jc_method _jc_javax_xml_transform_sax_SAXTransformerFactory$method_info$newXMLFilter$d1211602c6161dca;

// Virtual methods structure
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$vmethods {
	struct _jc_object	*(*newTemplatesHandler$17a5d9d759402a37)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*newTransformerHandler$bb837a0d83afae09)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*newTransformerHandler$88c4a0c08a9ede67)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*newTransformerHandler$35afbc0e42ee6f52)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*newXMLFilter$e60ae9ab4498aaeb)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*newXMLFilter$d1211602c6161dca)(_jc_env *, struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_transform_TransformerFactory$vmethods	javax_xml_transform_TransformerFactory;
	_jc_javax_xml_transform_sax_SAXTransformerFactory$vmethods	javax_xml_transform_sax_SAXTransformerFactory;
};

// Vtype
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$vtype {
	_jc_type			type;
	_jc_javax_xml_transform_sax_SAXTransformerFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$refs {
    _jc_javax_xml_transform_sax_SAXTransformerFactory$sub_refs	javax_xml_transform_sax_SAXTransformerFactory;
    _jc_javax_xml_transform_TransformerFactory$sub_refs	javax_xml_transform_TransformerFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_transform_TransformerFactory$sub_nonrefs	javax_xml_transform_TransformerFactory;
    _jc_javax_xml_transform_sax_SAXTransformerFactory$sub_nonrefs	javax_xml_transform_sax_SAXTransformerFactory;
};

// Object instance structure
struct _jc_javax_xml_transform_sax_SAXTransformerFactory$object {
	_jc_javax_xml_transform_sax_SAXTransformerFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_transform_sax_SAXTransformerFactory$vtype	*vtype;
	_jc_javax_xml_transform_sax_SAXTransformerFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_transform_sax_SAXTransformerFactory$vtype _jc_javax_xml_transform_sax_SAXTransformerFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_transform_sax_SAXTransformerFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_transform_sax_SAXTransformerFactory$class_object;

#endif	/* _JC_javax_xml_transform_sax_SAXTransformerFactory_H_ */
